utilities
=========

.. image:: https://zenodo.org/badge/5715/pyoceans/utilities.svg
   :target: https://zenodo.org/badge/latestdoi/5715/pyoceans/utilities
   :alt: doi
.. image:: http://img.shields.io/travis/pyoceans/utilities/master.svg?style=flat
   :target: https://travis-ci.org/pyoceans/utilities
   :alt: build status
.. image:: http://img.shields.io/badge/license-MIT-blue.svg?style=flat
   :target: https://github.com/pyoceans/utilities/blob/master/LICENSE
   :alt: license

IOOS/SECOORA utilities functions.
---------------------------------

A collection of misc functions used in IOOS/SECOORA notebooks.
Examples
`here <http://nbviewer.ipython.org/github/ioos/secoora/tree/master/notebooks/>`__
and
`here <http://nbviewer.ipython.org/github/ioos/system-test/tree/master/>`__.
